==> hollow-cli-1.3.9.tgz: package/esm/mwPlugins.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**************************************************
 * Created by nanyuantingfeng on 27/10/2017 16:25.
 **************************************************/
import path from 'path';
import { MiniCssExtractPlugin, FriendlyErrorsWebpackPlugin, ProgressPlugin, HashedModuleIdsPlugin, AggressiveSplittingPlugin, UglifyJsPlugin, OptimizeCSSAssetsPlugin, BundleAnalyzerPlugin, IgnorePlugin } from './plugins';
import { notifier, fnProgressHandler, getOptions } from './util';
export default function (_x, _x2) {
  return _ref.apply(this, arguments);
}

function _ref() {
  _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(context, next) {
    var hash, compress, plugins, dll, ENV, DIRs, filename, chunkFilename, cwd, outputPath, isDevServer, _context$records, records, _context$aggressive, aggressive, _context$analyzer, analyzer;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            context.plugins = [new FriendlyErrorsWebpackPlugin({
              onErrors: function onErrors(severity, errors) {
                if (severity !== 'error') {
                  notifier.notify({
                    title: 'hollow cli',
                    message: 'warn',
                    contentImage: path.join(__dirname, '../assets/warn.png'),
                    sound: 'Glass'
                  });
                  return;
                }

                var error = errors[0];
                notifier.notify({
                  title: 'hollow cli',
                  message: "".concat(severity, " : ").concat(error ? error.name : error),
                  subtitle: error ? error.file : error || '',
                  contentImage: path.join(__dirname, '../assets/fail.png'),
                  sound: 'Glass'
                });
              }
            }), new ProgressPlugin(fnProgressHandler), new HashedModuleIdsPlugin()];
            next();
            hash = context.hash, compress = context.compress, plugins = context.plugins, dll = context.dll, ENV = context.ENV, DIRs = context.DIRs;

            if (!Array.isArray(dll)) {
              context.webpackConfig.optimization.splitChunks = {
                chunks: 'all',
                name: 'vendors'
              };
              context.webpackConfig.optimization.runtimeChunk = true;
            }

            filename = hash ? '[name]-[hash].css' : '[name].css';
            chunkFilename = hash ? '[id]-[hash].css' : '[id].css';
            plugins.push(new MiniCssExtractPlugin({
              filename: filename,
              chunkFilename: chunkFilename
            }));
            context.webpackConfig.optimization.minimize = !!compress;

            if (compress) {
              context.webpackConfig.optimization.minimizer = [new UglifyJsPlugin({
                uglifyOptions: {
                  output: {
                    comments: false // remove comments

                  },
                  compress: {
                    unused: true,
                    dead_code: true,
                    // big one--strip code that will never execute
                    warnings: false,
                    // good for prod apps so users can't peek behind curtain
                    drop_debugger: true,
                    conditionals: true,
                    evaluate: true,
                    drop_console: true,
                    // strips console statements
                    sequences: true,
                    booleans: true
                  }
                },
                cache: true,
                parallel: true,
                sourceMap: false
              }), new OptimizeCSSAssetsPlugin()];
            }

            cwd = context.cwd, outputPath = context.outputPath, isDevServer = context.isDevServer, _context$records = context.records, records = _context$records === void 0 ? false : _context$records, _context$aggressive = context.aggressive, aggressive = _context$aggressive === void 0 ? true : _context$aggressive, _context$analyzer = context.analyzer, analyzer = _context$analyzer === void 0 ? false : _context$analyzer; // dll 模式下不能使用当前插件

            if (!Array.isArray(dll) && aggressive === true) {
              plugins.push(new AggressiveSplittingPlugin(getOptions(aggressive, {
                minSize: 1,
                maxSize: 1024 * 1024,
                chunkOverhead: 0,
                entryChunkMultiplicator: 1
              })));
            }

            context.plugins = plugins;

            if (records) {
              context.webpackConfig.recordsOutputPath = path.join(cwd, outputPath, getOptions(records, 'records.json'));
            }

            if (analyzer) {
              plugins.push(new BundleAnalyzerPlugin(getOptions(analyzer)));
            }

            plugins.push(new IgnorePlugin(/^\.\/locale$/, /moment$/));

          case 15:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _ref.apply(this, arguments);
}

==> hollow-cli-1.3.13.tgz: package/esm/mwPlugins.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**************************************************
 * Created by nanyuantingfeng on 27/10/2017 16:25.
 **************************************************/
import path from 'path';
import { MiniCssExtractPlugin, FriendlyErrorsWebpackPlugin, ProgressPlugin, HashedModuleIdsPlugin, AggressiveSplittingPlugin, UglifyJsPlugin, OptimizeCSSAssetsPlugin, BundleAnalyzerPlugin, IgnorePlugin, LodashWebpackPlugin } from './plugins';
import { notifier, fnProgressHandler, getOptions } from './util';
export default function (_x, _x2) {
  return _ref.apply(this, arguments);
}

function _ref() {
  _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(context, next) {
    var hash, compress, plugins, dll, ENV, DIRs, filename, chunkFilename, cwd, outputPath, _context$records, records, _context$aggressive, aggressive, _context$analyzer, analyzer, optimizeLodash;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            context.plugins = [new FriendlyErrorsWebpackPlugin({
              onErrors: function onErrors(severity, errors) {
                if (severity !== 'error') {
                  notifier.notify({
                    title: 'hollow cli',
                    message: 'warn',
                    contentImage: path.join(__dirname, '../assets/warn.png'),
                    sound: 'Glass'
                  });
                  return;
                }

                var error = errors[0];
                notifier.notify({
                  title: 'hollow cli',
                  message: "".concat(severity, " : ").concat(error ? error.name : error),
                  subtitle: error ? error.file : error || '',
                  contentImage: path.join(__dirname, '../assets/fail.png'),
                  sound: 'Glass'
                });
              }
            }), new ProgressPlugin(fnProgressHandler), new HashedModuleIdsPlugin()];
            next();
            hash = context.hash, compress = context.compress, plugins = context.plugins, dll = context.dll, ENV = context.ENV, DIRs = context.DIRs;

            if (!Array.isArray(dll)) {
              context.webpackConfig.optimization.splitChunks = {
                chunks: 'all',
                name: 'vendors'
              };
              context.webpackConfig.optimization.runtimeChunk = true;
            }

            filename = hash ? '[name]-[hash].css' : '[name].css';
            chunkFilename = hash ? '[id]-[hash].css' : '[id].css';
            plugins.push(new MiniCssExtractPlugin({
              filename: filename,
              chunkFilename: chunkFilename
            }));
            context.webpackConfig.optimization.minimize = !!compress;

            if (compress) {
              context.webpackConfig.optimization.minimizer = [new UglifyJsPlugin({
                uglifyOptions: {
                  output: {
                    comments: false // remove comments

                  },
                  compress: {
                    unused: true,
                    dead_code: true,
                    // big one--strip code that will never execute
                    warnings: false,
                    // good for prod apps so users can't peek behind curtain
                    drop_debugger: true,
                    conditionals: true,
                    evaluate: true,
                    drop_console: true,
                    // strips console statements
                    sequences: true,
                    booleans: true
                  }
                },
                cache: true,
                parallel: true,
                sourceMap: false
              }), new OptimizeCSSAssetsPlugin()];
            }

            cwd = context.cwd, outputPath = context.outputPath, _context$records = context.records, records = _context$records === void 0 ? false : _context$records, _context$aggressive = context.aggressive, aggressive = _context$aggressive === void 0 ? true : _context$aggressive, _context$analyzer = context.analyzer, analyzer = _context$analyzer === void 0 ? false : _context$analyzer, optimizeLodash = context.optimizeLodash; // dll 模式下不能使用当前插件

            if (!Array.isArray(dll) && aggressive === true) {
              plugins.push(new AggressiveSplittingPlugin(getOptions(aggressive, {
                minSize: 1,
                maxSize: 1024 * 1024,
                chunkOverhead: 0,
                entryChunkMultiplicator: 1
              })));
            }

            context.plugins = plugins;

            if (records) {
              context.webpackConfig.recordsOutputPath = path.join(cwd, outputPath, getOptions(records, 'records.json'));
            }

            if (analyzer) {
              plugins.push(new BundleAnalyzerPlugin(getOptions(analyzer)));
            }

            plugins.push(new IgnorePlugin(/^\.\/locale$/, /moment$/));

            if (optimizeLodash) {
              plugins.push(new LodashWebpackPlugin());
            }

          case 16:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _ref.apply(this, arguments);
}
